﻿using System.Windows.Input;

using DevExpress.Xpf.Mvvm;

namespace TestProject
{
    /// <summary>
    /// 상세 뷰 모델
    /// </summary>
    public class DetailViewModel : NavigationViewModelBase
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Property
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region Back 탐색 명령 - NavigateBackCommand

        /// <summary>
        /// Back 탐색 명령
        /// </summary>
        public ICommand NavigateBackCommand { get; private set; }

        #endregion

        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 탐색 서비스 - NavigationService

        /// <summary>
        /// 탐색 서비스
        /// </summary>
        private INavigationService NavigationService
        {
            get
            {
                return ServiceContainer.GetService<INavigationService>();
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - DetailViewModel()

        /// <summary>
        /// 생성자
        /// </summary>
        public DetailViewModel()
        {
            NavigateBackCommand = new DelegateCommand(NavigateBackCommand_Execute, NavigateBackCommand_CanExecute);
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Protected

        #region 탐색된 경우 처리하기 - OnNavigatedTo()

        /// <summary>
        /// 탐색된 경우 처리하기
        /// </summary>
        protected override void OnNavigatedTo()
        {
            base.OnNavigatedTo();

            (NavigateBackCommand as DelegateCommand).RaiseCanExecuteChanged();
        }

        #endregion

        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Back 탐색 명령 실행시 처리하기 - NavigateBackCommand_Execute()

        /// <summary>
        /// Back 탐색 명령 실행시 처리하기
        /// </summary>
        private void NavigateBackCommand_Execute()
        {
            NavigationService.GoBack();
        }

        #endregion
        #region Back 탐색 명령 실행 가능 여부 조사시 처리하기 - NavigateBackCommand_CanExecute()

        /// <summary>
        /// Back 탐색 명령 실행 가능 여부 조사시 처리하기
        /// </summary>
        /// <returns>Back 탐색 명령 실행 가능 여부</returns>
        private bool NavigateBackCommand_CanExecute()
        {
            return NavigationService != null && NavigationService.CanGoBack;
        }

        #endregion
    }
}